@@ -566,12 +566,15 @@ void *Calloc(size_t nmemb, size_t size);
 void *Malloc(size_t size);
 void *Realloc(void *ptr, size_t size);
 void wipeStr(char *str);
+void strCat(char **bp, const char *str);
+void strCatL(char **bp, const char *str, int max);
 int strCmp(const char *s1, const char *s2);
 #ifndef HAVE_STRNLEN
 int strnlen(const char *s, int max);
 #endif
 int strNDup(char **dst, const char *src, int len);
 int strDup(char **dst, const char *src);
+char *replaceInString(const char *str, const char *before, const char *after);
 int arrLen(char **arr);
 void freeStrArr(char **arr);
 char **initStrArr(char **arr);
@@ -580,6 +583,7 @@ char **xCopyStrArr(int rn, char **arr);
 int reStrN(char **dst, const char *src, int len);
 int reStr(char **dst, const char *src);
 int strApp(char **dst, ...);
+char **extStrArr(char **arr, char ***strp);
 char **addStrArr(char **arr, const char *str, int len);
 char **parseArgs(char **argv, const char *string);
 /* End note */
