@@ -519,7 +519,7 @@ void FancyPlotter::setTooltip()
         }
         if (beamId != sensor->beamId) {
             if (!sensor->summationName.isEmpty()) {
-                tooltip += i18nc("%1 is what is being shown statistics for, like 'Memory', 'Swap', etc.", "<p><b>%1:</b><br>", sensor->summationName);
+                tooltip += i18nc("%1 is what is being shown statistics for, like 'Memory', 'Swap', etc.", "<p><b>%1:</b><br>", i18n(sensor->summationName.toUtf8().constData()));
                 showingSummationGroup = true;
                 neednewline = false;
             } else if (showingSummationGroup) {
