@@ -34,9 +34,9 @@
 #include <QButtonGroup>
 #include <QLayout>
 #include <QGroupBox>
-#include <QtGui/QMouseEvent>
+#include <QMouseEvent>
 
-#include <QtGui/QX11Info>
+#include <QX11Info>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <X11/Xutil.h>
