@@ -54,6 +54,9 @@ public slots:
     void toggleWindow();
     void slotWindowClosed(KWin::EffectWindow *w);
 
+private Q_SLOTS:
+    void resetShader();
+
 protected:
     bool loadData();
 
