@@ -54,6 +54,10 @@ var maximizeEffect = {
                     value1: oldGeometry.x - newGeometry.x - (newGeometry.width / 2 - oldGeometry.width / 2),
                     value2: oldGeometry.y - newGeometry.y - (newGeometry.height / 2 - oldGeometry.height / 2)
                 }
+            }, {
+                type: Effect.CrossFadePrevious,
+                to: 1.0,
+                from: 0.0
             }]
         });
     },
