@@ -307,6 +307,14 @@ public:
      **/
     CompositingType recommendedCompositor() const;
 
+    /**
+     * Returns true if glMapBufferRange() is likely to perform worse than glBufferSubData()
+     * when updating an unused range of a buffer object, and false otherwise.
+     *
+     * @since 4.11
+     */
+    bool preferBufferSubData() const;
+
     /**
      * @returns a human readable form of the @p version.
      * @since 4.9
@@ -359,6 +367,7 @@ private:
     bool m_textureNPOT: 1;
     bool m_limitedNPOT: 1;
     bool m_virtualMachine: 1;
+    bool m_preferBufferSubData: 1;
     static GLPlatform *s_platform;
 };
 
