@@ -73,7 +73,9 @@ public:
     static bool sNPOTTextureSupported;
     static bool sFramebufferObjectSupported;
     static bool sSaturationSupported;
-    static bool sTextureFormatBGRA;
+    static GLenum sTextureFormat;
+    static uint s_fbo;
+    static uint s_textureObjectCounter;
 private:
     Q_DISABLE_COPY(GLTexturePrivate)
 };
