@@ -20,12 +20,17 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef KWIN_OUTLINE_H
 #define KWIN_OUTLINE_H
-#include <X11/X.h>
-#include <fixx11h.h>
-#include <QtCore/QRect>
-#include <QtCore/QVector>
+#include "xcbutils.h"
+#include <kwinglobals.h>
+#include <QRect>
+#include <QWidget>
+
+namespace Plasma {
+class FrameSvg;
+}
 
 namespace KWin {
+class OutlineVisual;
 
 /**
  * @short This class is used to show the outline of a given geometry.
@@ -38,9 +43,9 @@ namespace KWin {
  * @author Arthur Arlt
  * @since 4.7
  */
-class Outline {
+class Outline : public QObject {
+    Q_OBJECT
 public:
-    Outline();
     ~Outline();
 
     /**
@@ -73,32 +78,99 @@ public:
      */
     void hide();
 
-    /**
-     * Return outline window ids
-     * @return The window ids created to represent the outline
-     */
-    QVector<Window> windowIds() const;
+    const QRect &geometry() const;
+
+private Q_SLOTS:
+    void compositingChanged();
+
 private:
-
-    /**
-     * Show the window outline using the X implementation
-     */
-    void showWithX();
-
-    /**
-     * Hide previously shown outline used the X implementation
-     */
-    void hideWithX();
-
-    Window m_topOutline;
-    Window m_rightOutline;
-    Window m_bottomOutline;
-    Window m_leftOutline;
+    void createHelper();
+    QScopedPointer<OutlineVisual> m_visual;
     QRect m_outlineGeometry;
-    bool m_initialized;
     bool m_active;
+    KWIN_SINGLETON(Outline)
 };
 
+class OutlineVisual
+{
+public:
+    OutlineVisual(Outline *outline);
+    virtual ~OutlineVisual();
+    virtual void show() = 0;
+    virtual void hide() = 0;
+protected:
+    Outline *outline();
+    const Outline *outline() const;
+private:
+    Outline *m_outline;
+};
+
+class CompositedOutlineVisual : public QWidget, public OutlineVisual
+{
+public:
+    CompositedOutlineVisual(Outline *outline);
+    virtual ~CompositedOutlineVisual();
+    virtual void show();
+    virtual void hide();
+protected:
+    virtual void paintEvent(QPaintEvent *);
+private:
+    Plasma::FrameSvg *m_background;
+};
+
+class NonCompositedOutlineVisual : public OutlineVisual
+{
+public:
+    NonCompositedOutlineVisual(Outline *outline);
+    virtual ~NonCompositedOutlineVisual();
+    virtual void show();
+    virtual void hide();
+
+private:
+    // TODO: variadic template arguments for adding method arguments
+    template <typename T>
+    void forEachWindow(T method);
+    bool m_initialized;
+    Xcb::Window m_topOutline;
+    Xcb::Window m_rightOutline;
+    Xcb::Window m_bottomOutline;
+    Xcb::Window m_leftOutline;
+};
+
+inline
+const QRect &Outline::geometry() const
+{
+    return m_outlineGeometry;
+}
+
+inline
+Outline *OutlineVisual::outline()
+{
+    return m_outline;
+}
+
+inline
+const Outline *OutlineVisual::outline() const
+{
+    return m_outline;
+}
+
+template <typename T>
+inline
+void NonCompositedOutlineVisual::forEachWindow(T method)
+{
+    (m_topOutline.*method)();
+    (m_rightOutline.*method)();
+    (m_bottomOutline.*method)();
+    (m_leftOutline.*method)();
+}
+
+inline
+Outline *outline()
+{
+    return Outline::self();
+}
+
 }
 
 #endif
