@@ -22,14 +22,16 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <fixx11h.h>
 #include <kconfig.h>
+#include <KDE/KXMessages>
 #include <QRegExp>
 #include <ktemporaryfile.h>
 #include <QFile>
 #include <ktoolinvocation.h>
 
 #ifndef KCMRULES
-#include <QDesktopWidget>
 #include "client.h"
+#include "client_machine.h"
+#include "screens.h"
 #include "workspace.h"
 #endif
 
@@ -51,7 +53,7 @@ Rules::Rules()
     , maxsizerule(UnusedForceRule)
     , opacityactiverule(UnusedForceRule)
     , opacityinactiverule(UnusedForceRule)
-    , ignorepositionrule(UnusedForceRule)
+    , ignoregeometryrule(UnusedSetRule)
     , desktoprule(UnusedSetRule)
     , screenrule(UnusedSetRule)
     , activityrule(UnusedSetRule)
@@ -157,7 +159,7 @@ void Rules::readFromCfg(const KConfigGroup& cfg)
     READ_FORCE_RULE(opacityinactive, , 0);
     if (opacityinactive < 0 || opacityinactive > 100)
         opacityinactive = 100;
-    READ_FORCE_RULE(ignoreposition, , false);
+    READ_SET_RULE(ignoregeometry, , false);
     READ_SET_RULE(desktop, , 0);
     READ_SET_RULE(screen, , 0);
     READ_SET_RULE(activity, , QString());
@@ -247,7 +249,7 @@ void Rules::write(KConfigGroup& cfg) const
     WRITE_FORCE_RULE(maxsize,);
     WRITE_FORCE_RULE(opacityactive,);
     WRITE_FORCE_RULE(opacityinactive,);
-    WRITE_FORCE_RULE(ignoreposition,);
+    WRITE_SET_RULE(ignoregeometry,);
     WRITE_SET_RULE(desktop,);
     WRITE_SET_RULE(screen,);
     WRITE_SET_RULE(activity,);
@@ -289,7 +291,7 @@ bool Rules::isEmpty() const
            && maxsizerule == UnusedForceRule
            && opacityactiverule == UnusedForceRule
            && opacityinactiverule == UnusedForceRule
-           && ignorepositionrule == UnusedForceRule
+           && ignoregeometryrule == UnusedSetRule
            && desktoprule == UnusedSetRule
            && screenrule == UnusedSetRule
            && activityrule == UnusedSetRule
@@ -394,12 +396,12 @@ bool Rules::matchTitle(const QString& match_title) const
     return true;
 }
 
-bool Rules::matchClientMachine(const QByteArray& match_machine) const
+bool Rules::matchClientMachine(const QByteArray& match_machine, bool local) const
 {
     if (clientmachinematch != UnimportantMatch) {
         // if it's localhost, check also "localhost" before checking hostname
-        if (match_machine != "localhost" && isLocalMachine(match_machine)
-                && matchClientMachine("localhost"))
+        if (match_machine != "localhost" && local
+                && matchClientMachine("localhost", true))
             return true;
         if (clientmachinematch == RegExpMatch
                 && QRegExp(clientmachine).indexIn(match_machine) == -1)
@@ -425,7 +427,7 @@ bool Rules::match(const Client* c) const
         return false;
     if (!matchTitle(c->caption(false)))
         return false;
-    if (!matchClientMachine(c->wmClientMachine(false)))
+    if (!matchClientMachine(c->clientMachine()->hostName(), c->clientMachine()->isLocal()))
         return false;
     return true;
 }
@@ -581,13 +583,7 @@ APPLY_FORCE_RULE(minsize, MinSize, QSize)
 APPLY_FORCE_RULE(maxsize, MaxSize, QSize)
 APPLY_FORCE_RULE(opacityactive, OpacityActive, int)
 APPLY_FORCE_RULE(opacityinactive, OpacityInactive, int)
-APPLY_FORCE_RULE(ignoreposition, IgnorePosition, bool)
-
-// the cfg. entry needs to stay named the say for backwards compatibility
-bool Rules::applyIgnoreGeometry(bool& ignore) const
-{
-    return applyIgnorePosition(ignore);
-}
+APPLY_RULE(ignoregeometry, IgnoreGeometry, bool)
 
 APPLY_RULE(desktop, Desktop, int)
 APPLY_RULE(screen, Screen, int)
@@ -679,7 +675,7 @@ void Rules::discardUsed(bool withdrawn)
     DISCARD_USED_FORCE_RULE(maxsize);
     DISCARD_USED_FORCE_RULE(opacityactive);
     DISCARD_USED_FORCE_RULE(opacityinactive);
-    DISCARD_USED_FORCE_RULE(ignoreposition);
+    DISCARD_USED_SET_RULE(ignoregeometry);
     DISCARD_USED_SET_RULE(desktop);
     DISCARD_USED_SET_RULE(screen);
     DISCARD_USED_SET_RULE(activity);
@@ -741,7 +737,7 @@ void WindowRules::update(Client* c, int selection)
         if ((*it)->update(c, selection))    // no short-circuiting here
             updated = true;
     if (updated)
-        Workspace::self()->rulesUpdated();
+        RuleBook::self()->requestDiskStorage();
 }
 
 #define CHECK_RULE( rule, type ) \
@@ -789,12 +785,7 @@ CHECK_FORCE_RULE(MinSize, QSize)
 CHECK_FORCE_RULE(MaxSize, QSize)
 CHECK_FORCE_RULE(OpacityActive, int)
 CHECK_FORCE_RULE(OpacityInactive, int)
-CHECK_FORCE_RULE(IgnorePosition, bool)
-
-bool WindowRules::checkIgnoreGeometry(bool ignore) const
-{
-    return checkIgnorePosition(ignore);
-}
+CHECK_RULE(IgnoreGeometry, bool)
 
 CHECK_RULE(Desktop, int)
 CHECK_RULE(Activity, QString)
@@ -818,7 +809,7 @@ int WindowRules::checkScreen(int screen, bool init) const
         if ( (*it)->applyScreen( ret, init ))
             break;
     }
-    if (ret >= QApplication::desktop()->screenCount())
+    if (ret >= Screens::self()->count())
         ret = screen;
     return ret;
 }
@@ -850,7 +841,7 @@ CHECK_FORCE_RULE(DisableGlobalShortcuts, bool)
 
 void Client::setupWindowRules(bool ignore_temporary)
 {
-    client_rules = workspace()->findWindowRules(this, ignore_temporary);
+    client_rules = RuleBook::self()->find(this, ignore_temporary);
     // check only after getting the rules, because there may be a rule forcing window type
 }
 
@@ -866,7 +857,7 @@ void Client::applyWindowRules()
     if (geom != orig_geom)
         setGeometry(geom);
     // MinSize, MaxSize handled by Geometry
-    // IgnorePosition
+    // IgnoreGeometry
     setDesktop(desktop());
     workspace()->sendClientToScreen(this, screen());
     setOnActivities(activities());
@@ -911,7 +902,7 @@ void Client::updateWindowRules(Rules::Types selection)
 {
     if (!isManaged())  // not fully setup yet
         return;
-    if (workspace()->rulesUpdatesDisabled())
+    if (RuleBook::self()->areUpdatesDisabled())
         return;
     client_rules.update(this, selection);
 }
@@ -923,12 +914,37 @@ void Client::finishWindowRules()
 }
 
 // Workspace
+KWIN_SINGLETON_FACTORY(RuleBook)
 
-WindowRules Workspace::findWindowRules(const Client* c, bool ignore_temporary)
+RuleBook::RuleBook(QObject *parent)
+    : QObject(parent)
+    , m_updateTimer(new QTimer(this))
+    , m_updatesDisabled(false)
+    , m_temporaryRulesMessages(new KXMessages("_KDE_NET_WM_TEMPORARY_RULES", NULL, false)) // TODO KF5 - remove *then* obsolete last parameter which is *now* mandatory
+{
+    connect(m_temporaryRulesMessages.data(), SIGNAL(gotMessage(QString)), SLOT(temporaryRulesMessage(QString)));
+    connect(m_updateTimer, SIGNAL(timeout()), SLOT(save()));
+    m_updateTimer->setInterval(1000);
+    m_updateTimer->setSingleShot(true);
+}
+
+RuleBook::~RuleBook()
+{
+    save();
+    deleteAll();
+}
+
+void RuleBook::deleteAll()
+{
+    qDeleteAll(m_rules);
+    m_rules.clear();
+}
+
+WindowRules RuleBook::find(const Client* c, bool ignore_temporary)
 {
     QVector< Rules* > ret;
-    for (QList< Rules* >::Iterator it = rules.begin();
-            it != rules.end();
+    for (QList< Rules* >::Iterator it = m_rules.begin();
+            it != m_rules.end();
        ) {
         if (ignore_temporary && (*it)->isTemporary()) {
             ++it;
@@ -938,7 +954,7 @@ WindowRules Workspace::findWindowRules(const Client* c, bool ignore_temporary)
             Rules* rule = *it;
             kDebug(1212) << "Rule found:" << rule << ":" << c;
             if (rule->isTemporary())
-                it = rules.erase(it);
+                it = m_rules.erase(it);
             else
                 ++it;
             ret.append(rule);
@@ -949,9 +965,9 @@ WindowRules Workspace::findWindowRules(const Client* c, bool ignore_temporary)
     return WindowRules(ret);
 }
 
-void Workspace::editWindowRules(Client* c, bool whole_app)
+void RuleBook::edit(Client* c, bool whole_app)
 {
-    writeWindowRules();
+    save();
     QStringList args;
     args << "--wid" << QString::number(c->window());
     if (whole_app)
@@ -959,12 +975,9 @@ void Workspace::editWindowRules(Client* c, bool whole_app)
     KToolInvocation::kdeinitExec("kwin_rules_dialog", args);
 }
 
-void Workspace::loadWindowRules()
+void RuleBook::load()
 {
-    while (!rules.isEmpty()) {
-        delete rules.front();
-        rules.pop_front();
-    }
+    deleteAll();
     KConfig cfg(QLatin1String(KWIN_NAME) + "rulesrc", KConfig::NoGlobals);
     int count = cfg.group("General").readEntry("count", 0);
     for (int i = 1;
@@ -972,23 +985,23 @@ void Workspace::loadWindowRules()
             ++i) {
         KConfigGroup cg(&cfg, QString::number(i));
         Rules* rule = new Rules(cg);
-        rules.append(rule);
+        m_rules.append(rule);
     }
 }
 
-void Workspace::writeWindowRules()
+void RuleBook::save()
 {
-    rulesUpdatedTimer.stop();
+    m_updateTimer->stop();
     KConfig cfg(QLatin1String(KWIN_NAME) + "rulesrc", KConfig::NoGlobals);
     QStringList groups = cfg.groupList();
     for (QStringList::ConstIterator it = groups.constBegin();
             it != groups.constEnd();
             ++it)
         cfg.deleteGroup(*it);
-    cfg.group("General").writeEntry("count", rules.count());
+    cfg.group("General").writeEntry("count", m_rules.count());
     int i = 1;
-    for (QList< Rules* >::ConstIterator it = rules.constBegin();
-            it != rules.constEnd();
+    for (QList< Rules* >::ConstIterator it = m_rules.constBegin();
+            it != m_rules.constEnd();
             ++it) {
         if ((*it)->isTemporary())
             continue;
@@ -998,29 +1011,29 @@ void Workspace::writeWindowRules()
     }
 }
 
-void Workspace::gotTemporaryRulesMessage(const QString& message)
+void RuleBook::temporaryRulesMessage(const QString& message)
 {
     bool was_temporary = false;
-    for (QList< Rules* >::ConstIterator it = rules.constBegin();
-            it != rules.constEnd();
+    for (QList< Rules* >::ConstIterator it = m_rules.constBegin();
+            it != m_rules.constEnd();
             ++it)
         if ((*it)->isTemporary())
             was_temporary = true;
     Rules* rule = new Rules(message, true);
-    rules.prepend(rule);   // highest priority first
+    m_rules.prepend(rule);   // highest priority first
     if (!was_temporary)
         QTimer::singleShot(60000, this, SLOT(cleanupTemporaryRules()));
 }
 
-void Workspace::cleanupTemporaryRules()
+void RuleBook::cleanupTemporaryRules()
 {
     bool has_temporary = false;
-    for (QList< Rules* >::Iterator it = rules.begin();
-            it != rules.end();
+    for (QList< Rules* >::Iterator it = m_rules.begin();
+            it != m_rules.end();
        ) {
-        if ((*it)->discardTemporary(false))
-            it = rules.erase(it);
-        else {
+        if ((*it)->discardTemporary(false)) { // deletes (*it)
+            it = m_rules.erase(it);
+        } else {
             if ((*it)->isTemporary())
                 has_temporary = true;
             ++it;
@@ -1030,11 +1043,11 @@ void Workspace::cleanupTemporaryRules()
         QTimer::singleShot(60000, this, SLOT(cleanupTemporaryRules()));
 }
 
-void Workspace::discardUsedWindowRules(Client* c, bool withdrawn)
+void RuleBook::discardUsed(Client* c, bool withdrawn)
 {
     bool updated = false;
-    for (QList< Rules* >::Iterator it = rules.begin();
-            it != rules.end();
+    for (QList< Rules* >::Iterator it = m_rules.begin();
+            it != m_rules.end();
        ) {
         if (c->rules()->contains(*it)) {
             updated = true;
@@ -1042,7 +1055,7 @@ void Workspace::discardUsedWindowRules(Client* c, bool withdrawn)
             if ((*it)->isEmpty()) {
                 c->removeRule(*it);
                 Rules* r = *it;
-                it = rules.erase(it);
+                it = m_rules.erase(it);
                 delete r;
                 continue;
             }
@@ -1050,20 +1063,19 @@ void Workspace::discardUsedWindowRules(Client* c, bool withdrawn)
         ++it;
     }
     if (updated)
-        rulesUpdated();
+        requestDiskStorage();
 }
 
-void Workspace::rulesUpdated()
+void RuleBook::requestDiskStorage()
 {
-    rulesUpdatedTimer.setSingleShot(true);
-    rulesUpdatedTimer.start(1000);
+    m_updateTimer->start();
 }
 
-void Workspace::disableRulesUpdates(bool disable)
+void RuleBook::setUpdatesDisabled(bool disable)
 {
-    rules_updates_disabled = disable;
+    m_updatesDisabled = disable;
     if (!disable) {
-        foreach (Client * c, clients)
+        foreach (Client * c, Workspace::self()->clientList())
             c->updateWindowRules(Rules::All);
     }
 }
