@@ -4,7 +4,7 @@
 
 Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 Copyright (C) 2003 Lubos Lunak <l.lunak@kde.org>
-Copyright (C) 2009 Martin Gräßlin <kde@martin-graesslin.com>
+Copyright (C) 2009 Martin Gräßlin <mgraesslin@kde.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,9 +27,20 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "tabbox/clientmodel.h"
 #include "tabbox/desktopmodel.h"
 #include "tabbox/tabboxconfig.h"
+#include "tabbox/desktopchain.h"
 // kwin
+#ifdef KWIN_BUILD_ACTIVITIES
+#include "activities.h"
+#endif
 #include "client.h"
 #include "effects.h"
+#include "focuschain.h"
+#ifdef KWIN_BUILD_SCREENEDGES
+#include "screenedge.h"
+#endif
+#include "screens.h"
+#include "unmanaged.h"
+#include "virtualdesktops.h"
 #include "workspace.h"
 // Qt
 #include <QAction>
@@ -41,13 +52,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KConfigGroup>
 #include <KDE/KAction>
 #include <KDebug>
-#include <KLocale>
+#include <KDE/KIcon>
+#include <KDE/KGlobal>
+#include <KLocalizedString>
 #include <kkeyserver.h>
 // X11
 #include <fixx11h.h>
 #include <X11/keysym.h>
 #include <X11/keysymdef.h>
-#include "outline.h"
 
 // specify externals before namespace
 
@@ -62,7 +74,15 @@ namespace TabBox
 TabBoxHandlerImpl::TabBoxHandlerImpl(TabBox* tabBox)
     : TabBoxHandler()
     , m_tabBox(tabBox)
+    , m_desktopFocusChain(new DesktopChainManager(this))
 {
+    // connects for DesktopFocusChainManager
+    VirtualDesktopManager *vds = VirtualDesktopManager::self();
+    connect(vds, SIGNAL(countChanged(uint,uint)), m_desktopFocusChain, SLOT(resize(uint,uint)));
+    connect(vds, SIGNAL(currentChanged(uint,uint)), m_desktopFocusChain, SLOT(addDesktop(uint,uint)));
+#ifdef KWIN_BUILD_ACTIVITIES
+    connect(Activities::self(), SIGNAL(currentChanged(QString)), m_desktopFocusChain, SLOT(useChain(QString)));
+#endif
 }
 
 TabBoxHandlerImpl::~TabBoxHandlerImpl()
@@ -71,32 +91,32 @@ TabBoxHandlerImpl::~TabBoxHandlerImpl()
 
 int TabBoxHandlerImpl::activeScreen() const
 {
-    return Workspace::self()->activeScreen();
+    return screens()->current();
 }
 
 int TabBoxHandlerImpl::currentDesktop() const
 {
-    return Workspace::self()->currentDesktop();
+    return VirtualDesktopManager::self()->current();
 }
 
 QString TabBoxHandlerImpl::desktopName(TabBoxClient* client) const
 {
     if (TabBoxClientImpl* c = static_cast< TabBoxClientImpl* >(client)) {
         if (!c->client()->isOnAllDesktops())
-            return Workspace::self()->desktopName(c->client()->desktop());
+            return VirtualDesktopManager::self()->name(c->client()->desktop());
     }
-    return Workspace::self()->desktopName(Workspace::self()->currentDesktop());
+    return VirtualDesktopManager::self()->name(VirtualDesktopManager::self()->current());
 }
 
 QString TabBoxHandlerImpl::desktopName(int desktop) const
 {
-    return Workspace::self()->desktopName(desktop);
+    return VirtualDesktopManager::self()->name(desktop);
 }
 
 QWeakPointer<TabBoxClient> TabBoxHandlerImpl::nextClientFocusChain(TabBoxClient* client) const
 {
     if (TabBoxClientImpl* c = static_cast< TabBoxClientImpl* >(client)) {
-        Client* next = Workspace::self()->tabBox()->nextClientFocusChain(c->client());
+        Client* next = FocusChain::self()->nextMostRecentlyUsed(c->client());
         if (next)
             return next->tabBoxClient();
     }
@@ -105,7 +125,7 @@ QWeakPointer<TabBoxClient> TabBoxHandlerImpl::nextClientFocusChain(TabBoxClient*
 
 QWeakPointer< TabBoxClient > TabBoxHandlerImpl::firstClientFocusChain() const
 {
-    if (Client *c = m_tabBox->firstClientFocusChain()) {
+    if (Client *c = FocusChain::self()->firstMostRecentlyUsed()) {
         return QWeakPointer<TabBoxClient>(c->tabBoxClient());
     } else {
         return QWeakPointer<TabBoxClient>();
@@ -115,19 +135,19 @@ QWeakPointer< TabBoxClient > TabBoxHandlerImpl::firstClientFocusChain() const
 bool TabBoxHandlerImpl::isInFocusChain(TabBoxClient *client) const
 {
     if (TabBoxClientImpl *c = static_cast<TabBoxClientImpl*>(client)) {
-        return Workspace::self()->globalFocusChain().contains(c->client());
+        return FocusChain::self()->contains(c->client());
     }
     return false;
 }
 
 int TabBoxHandlerImpl::nextDesktopFocusChain(int desktop) const
 {
-    return m_tabBox->nextDesktopFocusChain(desktop);
+    return m_desktopFocusChain->next(desktop);
 }
 
 int TabBoxHandlerImpl::numberOfDesktops() const
 {
-    return Workspace::self()->numberOfDesktops();
+    return VirtualDesktopManager::self()->count();
 }
 
 QWeakPointer<TabBoxClient> TabBoxHandlerImpl::activeClient() const
@@ -219,15 +239,14 @@ bool TabBoxHandlerImpl::checkMinimized(TabBoxClient* client) const
 bool TabBoxHandlerImpl::checkMultiScreen(TabBoxClient* client) const
 {
     Client* current = (static_cast< TabBoxClientImpl* >(client))->client();
-    Workspace* workspace = Workspace::self();
 
     switch (config().clientMultiScreenMode()) {
     case TabBoxConfig::IgnoreMultiScreen:
         return true;
     case TabBoxConfig::ExcludeCurrentScreenClients:
-        return current->screen() != workspace->activeScreen();
+        return current->screen() != screens()->current();
     default:       // TabBoxConfig::OnlyCurrentScreenClients
-        return current->screen() == workspace->activeScreen();
+        return current->screen() == screens()->current();
     }
 }
 
@@ -274,6 +293,10 @@ TabBoxClientList TabBoxHandlerImpl::stackingOrder() const
     return ret;
 }
 
+bool TabBoxHandlerImpl::isKWinCompositing() const {
+    return Workspace::self()->compositing();
+}
+
 void TabBoxHandlerImpl::raiseClient(TabBoxClient* c) const
 {
     Workspace::self()->raiseClient(static_cast<TabBoxClientImpl*>(c)->client());
@@ -287,13 +310,10 @@ void TabBoxHandlerImpl::restack(TabBoxClient *c, TabBoxClient *under)
 
 void TabBoxHandlerImpl::elevateClient(TabBoxClient *c, WId tabbox, bool b) const
 {
-    if (effects) {
-        const Client *cl = static_cast<TabBoxClientImpl*>(c)->client();
-        if (EffectWindow *w = static_cast<EffectsHandlerImpl*>(effects)->findWindow(cl->window()))
-            static_cast<EffectsHandlerImpl*>(effects)->setElevatedWindow(w, b);
-        if (EffectWindow *w = static_cast<EffectsHandlerImpl*>(effects)->findWindow(tabbox))
-            static_cast<EffectsHandlerImpl*>(effects)->setElevatedWindow(w, b);
-    }
+    Client *cl = static_cast<TabBoxClientImpl*>(c)->client();
+    cl->elevate(b);
+    if (Unmanaged *w = Workspace::self()->findUnmanaged(WindowMatchPredicate(tabbox)))
+        w->elevate(b);
 }
 
 
@@ -301,28 +321,13 @@ QWeakPointer<TabBoxClient> TabBoxHandlerImpl::desktopClient() const
 {
     foreach (Toplevel *toplevel, Workspace::self()->stackingOrder()) {
         Client *client = qobject_cast<Client*>(toplevel);
-        if (client && client->isDesktop() && client->isOnCurrentDesktop() && client->screen() == Workspace::self()->activeScreen()) {
+        if (client && client->isDesktop() && client->isOnCurrentDesktop() && client->screen() == screens()->current()) {
             return client->tabBoxClient();
         }
     }
     return QWeakPointer<TabBoxClient>();
 }
 
-void TabBoxHandlerImpl::showOutline(const QRect &outline)
-{
-    Workspace::self()->outline()->show(outline);
-}
-
-void TabBoxHandlerImpl::hideOutline()
-{
-    Workspace::self()->outline()->hide();
-}
-
-QVector< Window > TabBoxHandlerImpl::outlineWindowIds() const
-{
-    return Workspace::self()->outline()->windowIds();
-}
-
 void TabBoxHandlerImpl::activateAndClose()
 {
     m_tabBox->accept();
@@ -406,6 +411,15 @@ bool TabBoxClientImpl::isFirstInTabBox() const
 /*********************************************************
 * TabBox
 *********************************************************/
+TabBox *TabBox::s_self = NULL;
+
+TabBox *TabBox::create(QObject *parent)
+{
+    Q_ASSERT(!s_self);
+    s_self = new TabBox(parent);
+    return s_self;
+}
+
 TabBox::TabBox(QObject *parent)
     : QObject(parent)
     , m_displayRefcount(0)
@@ -466,6 +480,7 @@ TabBox::TabBox(QObject *parent)
 TabBox::~TabBox()
 {
     QDBusConnection::sessionBus().unregisterObject("/TabBox");
+    s_self = NULL;
 }
 
 void TabBox::handlerReady()
@@ -561,7 +576,7 @@ void TabBox::reset(bool partial_reset)
         m_tabBox->createModel();
 
         if (!partial_reset)
-            setCurrentDesktop(Workspace::self()->currentDesktop());
+            setCurrentDesktop(VirtualDesktopManager::self()->current());
         break;
     }
 
@@ -600,7 +615,7 @@ ClientList TabBox::currentClientList()
 {
     TabBoxClientList list = m_tabBox->clientList();
     ClientList ret;
-    foreach (QWeakPointer<TabBoxClient> clientPointer, list) {
+    foreach (const QWeakPointer<TabBoxClient> &clientPointer, list) {
         QSharedPointer<TabBoxClient> client = clientPointer.toStrongRef();
         if (!client)
             continue;
@@ -713,6 +728,31 @@ void TabBox::reconfigure()
 
     m_delayShow = config.readEntry<bool>("ShowDelay", true);
     m_delayShowTime = config.readEntry<int>("DelayTime", 90);
+
+    m_desktopConfig.setLayoutName(config.readEntry("DesktopLayout", "informative"));
+    m_desktopListConfig.setLayoutName(config.readEntry("DesktopListLayout", "informative"));
+
+#ifdef KWIN_BUILD_SCREENEDGES
+    QList<ElectricBorder> *borders = &m_borderActivate;
+    QString borderConfig = "BorderActivate";
+    for (int i = 0; i < 2; ++i) {
+        foreach (ElectricBorder border, *borders) {
+            ScreenEdges::self()->unreserve(border, this);
+        }
+        borders->clear();
+        QStringList list = config.readEntry(borderConfig, QStringList());
+        foreach (const QString &s, list) {
+            bool ok;
+            const int i = s.toInt(&ok);
+            if (!ok)
+                continue;
+            borders->append(ElectricBorder(i));
+            ScreenEdges::self()->reserve(ElectricBorder(i), this, "toggle");
+        }
+        borders = &m_borderAlternativeActivate;
+        borderConfig = "BorderAlternativeActivate";
+    }
+#endif
 }
 
 void TabBox::loadConfig(const KConfigGroup& config, TabBoxConfig& tabBoxConfig)
@@ -732,8 +772,6 @@ void TabBox::loadConfig(const KConfigGroup& config, TabBoxConfig& tabBoxConfig)
     tabBoxConfig.setClientSwitchingMode(TabBoxConfig::ClientSwitchingMode(
                                             config.readEntry<int>("SwitchingMode", TabBoxConfig::defaultSwitchingMode())));
 
-    tabBoxConfig.setShowOutline(config.readEntry<bool>("ShowOutline",
-                                TabBoxConfig::defaultShowOutline()));
     tabBoxConfig.setShowTabBox(config.readEntry<bool>("ShowTabBox",
                                TabBoxConfig::defaultShowTabBox()));
     tabBoxConfig.setHighlightWindows(config.readEntry<bool>("HighlightWindows",
@@ -904,8 +942,9 @@ static bool areModKeysDepressed(const KShortcut& cut)
 
 void TabBox::navigatingThroughWindows(bool forward, const KShortcut& shortcut, TabBoxMode mode)
 {
-    if (isGrabbed())
+    if (!m_ready || isGrabbed() || !Workspace::self()->isOnCurrentHead()) {
         return;
+    }
     if (!options->focusPolicyIsReasonable()) {
         //ungrabXKeyboard(); // need that because of accelerator raw mode
         // CDE style raise / lower
@@ -923,75 +962,49 @@ void TabBox::navigatingThroughWindows(bool forward, const KShortcut& shortcut, T
 
 void TabBox::slotWalkThroughWindows()
 {
-    if (!m_ready){
-        return;
-    }
     navigatingThroughWindows(true, m_cutWalkThroughWindows, TabBoxWindowsMode);
 }
 
 void TabBox::slotWalkBackThroughWindows()
 {
-    if (!m_ready){
-        return;
-    }
     navigatingThroughWindows(false, m_cutWalkThroughWindowsReverse, TabBoxWindowsMode);
 }
 
 void TabBox::slotWalkThroughWindowsAlternative()
 {
-    if (!m_ready){
-        return;
-    }
     navigatingThroughWindows(true, m_cutWalkThroughWindowsAlternative, TabBoxWindowsAlternativeMode);
 }
 
 void TabBox::slotWalkBackThroughWindowsAlternative()
 {
-    if (!m_ready){
-        return;
-    }
     navigatingThroughWindows(false, m_cutWalkThroughWindowsAlternativeReverse, TabBoxWindowsAlternativeMode);
 }
 
 void TabBox::slotWalkThroughCurrentAppWindows()
 {
-    if (!m_ready){
-        return;
-    }
     navigatingThroughWindows(true, m_cutWalkThroughCurrentAppWindows, TabBoxCurrentAppWindowsMode);
 }
 
 void TabBox::slotWalkBackThroughCurrentAppWindows()
 {
-    if (!m_ready){
-        return;
-    }
     navigatingThroughWindows(false, m_cutWalkThroughCurrentAppWindowsReverse, TabBoxCurrentAppWindowsMode);
 }
 
 void TabBox::slotWalkThroughCurrentAppWindowsAlternative()
 {
-    if (!m_ready){
-        return;
-    }
     navigatingThroughWindows(true, m_cutWalkThroughCurrentAppWindowsAlternative, TabBoxCurrentAppWindowsAlternativeMode);
 }
 
 void TabBox::slotWalkBackThroughCurrentAppWindowsAlternative()
 {
-    if (!m_ready){
-        return;
-    }
     navigatingThroughWindows(false, m_cutWalkThroughCurrentAppWindowsAlternativeReverse, TabBoxCurrentAppWindowsAlternativeMode);
 }
 
 void TabBox::slotWalkThroughDesktops()
 {
-    if (!m_ready){
+    if (!m_ready || isGrabbed() || !Workspace::self()->isOnCurrentHead()) {
         return;
     }
-    if (isGrabbed())
-        return;
     if (areModKeysDepressed(m_cutWalkThroughDesktops)) {
         if (startWalkThroughDesktops())
             walkThroughDesktops(true);
@@ -1002,11 +1015,9 @@ void TabBox::slotWalkThroughDesktops()
 
 void TabBox::slotWalkBackThroughDesktops()
 {
-    if (!m_ready){
+    if (!m_ready || isGrabbed() || !Workspace::self()->isOnCurrentHead()) {
         return;
     }
-    if (isGrabbed())
-        return;
     if (areModKeysDepressed(m_cutWalkThroughDesktopsReverse)) {
         if (startWalkThroughDesktops())
             walkThroughDesktops(false);
@@ -1017,11 +1028,9 @@ void TabBox::slotWalkBackThroughDesktops()
 
 void TabBox::slotWalkThroughDesktopList()
 {
-    if (!m_ready){
+    if (!m_ready || isGrabbed() || !Workspace::self()->isOnCurrentHead()) {
         return;
     }
-    if (isGrabbed())
-        return;
     if (areModKeysDepressed(m_cutWalkThroughDesktopList)) {
         if (startWalkThroughDesktopList())
             walkThroughDesktops(true);
@@ -1032,11 +1041,9 @@ void TabBox::slotWalkThroughDesktopList()
 
 void TabBox::slotWalkBackThroughDesktopList()
 {
-    if (!m_ready){
+    if (!m_ready || isGrabbed() || !Workspace::self()->isOnCurrentHead()) {
         return;
     }
-    if (isGrabbed())
-        return;
     if (areModKeysDepressed(m_cutWalkThroughDesktopListReverse)) {
         if (startWalkThroughDesktopList())
             walkThroughDesktops(false);
@@ -1125,6 +1132,27 @@ void TabBox::modalActionsSwitch(bool enabled)
     action->setEnabled(enabled);
 }
 
+bool TabBox::toggle(ElectricBorder eb)
+{
+    if (!options->focusPolicyIsReasonable())
+        return false; // not supported.
+    if (isDisplayed()) {
+        ungrabXKeyboard();
+        accept();
+        return true;
+    }
+    if (!grabXKeyboard())
+        return false;
+    m_noModifierGrab = m_tabGrab = true;
+    if (m_borderAlternativeActivate.contains(eb))
+        setMode(TabBoxWindowsAlternativeMode);
+    else
+        setMode(TabBoxWindowsMode);
+    reset();
+    show();
+    return true;
+}
+
 void TabBox::open(bool modal, const QString &layout)
 {
     if (isDisplayed()) {
@@ -1499,93 +1527,21 @@ void TabBox::keyRelease(const XKeyEvent& ev)
         m_tabGrab = old_tab_grab;
         if (desktop != -1) {
             setCurrentDesktop(desktop);
-            Workspace::self()->setCurrentDesktop(desktop);
+            VirtualDesktopManager::self()->setCurrent(desktop);
         }
     }
 }
 
-int TabBox::nextDesktopFocusChain(int iDesktop) const
-{
-    const QVector<int> &desktopFocusChain = Workspace::self()->desktopFocusChain();
-    int i = desktopFocusChain.indexOf(iDesktop);
-    if (i >= 0 && i + 1 < desktopFocusChain.size())
-        return desktopFocusChain[i+1];
-    else if (desktopFocusChain.size() > 0)
-        return desktopFocusChain[ 0 ];
-    else
-        return 1;
-}
-
-int TabBox::previousDesktopFocusChain(int iDesktop) const
-{
-    const QVector<int> &desktopFocusChain = Workspace::self()->desktopFocusChain();
-    int i = desktopFocusChain.indexOf(iDesktop);
-    if (i - 1 >= 0)
-        return desktopFocusChain[i-1];
-    else if (desktopFocusChain.size() > 0)
-        return desktopFocusChain[desktopFocusChain.size()-1];
-    else
-        return Workspace::self()->numberOfDesktops();
-}
-
 int TabBox::nextDesktopStatic(int iDesktop) const
 {
-    int i = ++iDesktop;
-    if (i > Workspace::self()->numberOfDesktops())
-        i = 1;
-    return i;
+    DesktopNext functor;
+    return functor(iDesktop, true);
 }
 
 int TabBox::previousDesktopStatic(int iDesktop) const
 {
-    int i = --iDesktop;
-    if (i < 1)
-        i = Workspace::self()->numberOfDesktops();
-    return i;
-}
-
-/*!
-  auxiliary functions to travers all clients according to the focus
-  order. Useful for kwms Alt-tab feature.
-*/
-Client* TabBox::nextClientFocusChain(Client* c) const
-{
-    const ClientList &globalFocusChain = Workspace::self()->globalFocusChain();
-    if (globalFocusChain.isEmpty())
-        return 0;
-    int pos = globalFocusChain.indexOf(c);
-    if (pos == -1)
-        return globalFocusChain.last();
-    if (pos == 0)
-        return globalFocusChain.last();
-    pos--;
-    return globalFocusChain[ pos ];
-}
-
-/*!
-  auxiliary functions to travers all clients according to the focus
-  order. Useful for kwms Alt-tab feature.
-*/
-Client* TabBox::previousClientFocusChain(Client* c) const
-{
-    const ClientList &globalFocusChain = Workspace::self()->globalFocusChain();
-    if (globalFocusChain.isEmpty())
-        return 0;
-    int pos = globalFocusChain.indexOf(c);
-    if (pos == -1)
-        return globalFocusChain.first();
-    pos++;
-    if (pos == globalFocusChain.count())
-        return globalFocusChain.first();
-    return globalFocusChain[ pos ];
-}
-
-Client *TabBox::firstClientFocusChain() const
-{
-    const ClientList &globalFocusChain = Workspace::self()->globalFocusChain();
-    if (globalFocusChain.isEmpty())
-        return NULL;
-    return globalFocusChain.first();
+    DesktopPrevious functor;
+    return functor(iDesktop, true);
 }
 
 /*!
