@@ -36,9 +36,6 @@
 
 #include "ui_BackgroundDialog.h"
 
-typedef QPair<QString, QString> WallpaperInfo;
-Q_DECLARE_METATYPE(WallpaperInfo)
-
 // From kcategorizeditemsviewdelegate by Ivan Cukic
 #define EMBLEM_ICON_SIZE 16
 #define UNIVERSAL_PADDING 6
@@ -48,7 +45,7 @@ Q_DECLARE_METATYPE(WallpaperInfo)
 class AppletDelegate : public QAbstractItemDelegate
 {
 public:
-    enum { DescriptionRole = Qt::UserRole + 1, PluginNameRole };
+    enum { DescriptionRole = Qt::UserRole + 1, PluginNameRole, ModeRole };
 
     AppletDelegate(QObject * parent = 0);
 
@@ -78,13 +75,21 @@ void AppletDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option
     bool leftToRight = (painter->layoutDirection() == Qt::LeftToRight);
     QIcon::Mode iconMode = QIcon::Normal;
 
-    QColor foregroundColor = (option.state.testFlag(QStyle::State_Selected)) ?
-        option.palette.color(QPalette::HighlightedText) : option.palette.color(QPalette::Text);
+    const QColor foregroundColor = (option.state.testFlag(QStyle::State_Selected)) ?
+                                    option.palette.color(QPalette::HighlightedText) :
+                                    option.palette.color(QPalette::Text);
 
-    // Painting main column
-    QFont titleFont = option.font;
-    titleFont.setBold(true);
-    titleFont.setPointSize(titleFont.pointSize() + 2);
+    // Borrowed from Dolphin for consistency and beauty.
+    // For the color of the additional info the inactive text color
+    // is not used as this might lead to unreadable text for some color schemes. Instead
+    // the text color is slightly mixed with the background color.
+    const QColor textColor = option.palette.text().color();
+    const QColor baseColor = option.palette.base().color();
+    const int p1 = 70;
+    const int p2 = 100 - p1;
+    const QColor detailsColor = QColor((textColor.red() * p1 + baseColor.red() * p2) / 100,
+                                       (textColor.green() * p1 + baseColor.green() * p2) / 100,
+                                       (textColor.blue() * p1 + baseColor.blue() * p2) /  100);
 
     QPixmap pixmap(width, height);
     pixmap.fill(Qt::transparent);
@@ -102,11 +107,10 @@ void AppletDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option
     int textInner = 2 * UNIVERSAL_PADDING + MAIN_ICON_SIZE;
 
     p.setPen(foregroundColor);
-    p.setFont(titleFont);
     p.drawText(left + (leftToRight ? textInner : 0),
                top, width - textInner, height / 2,
                Qt::AlignBottom | Qt::AlignLeft, title);
-    p.setFont(option.font);
+    p.setPen(detailsColor);
     p.drawText(left + (leftToRight ? textInner : 0),
                top + height / 2,
                width - textInner, height / 2,
@@ -152,11 +156,7 @@ void AppletDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option
 int AppletDelegate::calcItemHeight(const QStyleOptionViewItem& option) const
 {
     // Painting main column
-    QFont titleFont = option.font;
-    titleFont.setBold(true);
-    titleFont.setPointSize(titleFont.pointSize() + 2);
-
-    int textHeight = QFontInfo(titleFont).pixelSize() + QFontInfo(option.font).pixelSize();
+    int textHeight = QFontInfo(option.font).pixelSize() * 2;
     //kDebug() << textHeight << qMax(textHeight, MAIN_ICON_SIZE) + 2 * UNIVERSAL_PADDING;
     return qMax(textHeight, MAIN_ICON_SIZE) + 2 * UNIVERSAL_PADDING;
 }
@@ -178,6 +178,7 @@ public:
     BackgroundDialogPrivate(BackgroundDialog* dialog, Plasma::Containment* c, Plasma::View* v)
      : q(dialog),
        containmentModel(0),
+       wallpaperModel(0),
        wallpaper(0),
        view(v),
        containment(c),
@@ -195,6 +196,7 @@ public:
     Ui::BackgroundDialog backgroundDialogUi;
 
     QStandardItemModel* containmentModel;
+    QStandardItemModel* wallpaperModel;
     Plasma::Wallpaper* wallpaper;
     Plasma::View* view;
     QWeakPointer<Plasma::Containment> containment;
@@ -282,6 +284,10 @@ BackgroundDialog::BackgroundDialog(const QSize& res, Plasma::Containment *c, Pla
         connect(this, SIGNAL(okClicked()), d->containment.data(), SLOT(configDialogFinished()));
     }
 
+    d->wallpaperModel = new QStandardItemModel(this);
+    d->backgroundDialogUi.wallpaperMode->setModel(d->wallpaperModel);
+    d->backgroundDialogUi.wallpaperMode->setItemDelegate(new AppletDelegate());
+
     QSize dialogSize = QSize(650, 720).expandedTo(sizeHint());
     if (d->containment) {
         const int screen = d->containment.data()->screen();
@@ -396,7 +402,7 @@ void BackgroundDialog::reloadConfig()
             sortedPlugins.insert(info.name(), info);
         }
 
-        d->backgroundDialogUi.wallpaperMode->clear();
+        d->wallpaperModel->clear();
         int i = 0;
         foreach (const KPluginInfo& info, sortedPlugins) {
             //kDebug() << "doing wallpaper" << info.pluginName() << currentPlugin;
@@ -409,8 +415,15 @@ void BackgroundDialog::reloadConfig()
                 }
 
                 foreach (const KServiceAction& mode, modes) {
-                    d->backgroundDialogUi.wallpaperMode->addItem(KIcon(mode.icon()), mode.text(),
-                                    QVariant::fromValue(WallpaperInfo(info.pluginName(), mode.name())));
+                    QStandardItem *item = new QStandardItem(KIcon(mode.icon()), mode.text());
+                    KConfig config(KGlobal::dirs()->locate("services", info.entryPath()),
+                                   KConfig::SimpleConfig);
+                    KConfigGroup cg(&config, "Desktop Action " + mode.name());
+                    item->setData(cg.readEntry("Comment", QString()), AppletDelegate::DescriptionRole);
+                    item->setData(info.pluginName(), AppletDelegate::PluginNameRole);
+                    item->setData(mode.name(), AppletDelegate::ModeRole);
+                    d->wallpaperModel->appendRow(item);
+
                     //kDebug() << matches << mode.name() << currentMode;
                     if (matches && mode.name() == currentMode) {
                         wallpaperIndex = i;
@@ -419,8 +432,11 @@ void BackgroundDialog::reloadConfig()
                     ++i;
                 }
             } else {
-                d->backgroundDialogUi.wallpaperMode->addItem(KIcon(info.icon()), info.name(),
-                                QVariant::fromValue(WallpaperInfo(info.pluginName(), QString())));
+                QStandardItem *item = new QStandardItem(KIcon(info.icon()), info.name());
+                item->setData(info.comment(), AppletDelegate::DescriptionRole);
+                item->setData(info.pluginName(), AppletDelegate::PluginNameRole);
+                d->wallpaperModel->appendRow(item);
+
                 if (matches) {
                     wallpaperIndex = i;
                     //kDebug() << "matches at" << wallpaperIndex;
@@ -440,11 +456,12 @@ void BackgroundDialog::reloadConfig()
     settingsModified(false);
 }
 
-void BackgroundDialog::changeBackgroundMode(int mode)
+void BackgroundDialog::changeBackgroundMode(int index)
 {
     kDebug();
     QWidget* w = 0;
-    WallpaperInfo wallpaperInfo = d->backgroundDialogUi.wallpaperMode->itemData(mode).value<WallpaperInfo>();
+    const QString plugin = d->backgroundDialogUi.wallpaperMode->itemData(index, AppletDelegate::PluginNameRole).toString();
+    const QString mode = d->backgroundDialogUi.wallpaperMode->itemData(index, AppletDelegate::ModeRole).toString();
 
     if (d->backgroundDialogUi.wallpaperGroup->layout()->count() > 1) {
         QLayoutItem *item = d->backgroundDialogUi.wallpaperGroup->layout()->takeAt(1);
@@ -453,21 +470,21 @@ void BackgroundDialog::changeBackgroundMode(int mode)
         delete widget;
     }
 
-    if (d->wallpaper && d->wallpaper->pluginName() != wallpaperInfo.first) {
+    if (d->wallpaper && d->wallpaper->pluginName() != plugin) {
         delete d->wallpaper;
         d->wallpaper = 0;
     }
 
     if (!d->wallpaper) {
-        d->wallpaper = Plasma::Wallpaper::load(wallpaperInfo.first);
+        d->wallpaper = Plasma::Wallpaper::load(plugin);
     }
 
     if (d->wallpaper) {
         d->wallpaper->setPreviewing(true);
         d->preview->setPreview(d->wallpaper);
-        d->wallpaper->setRenderingMode(wallpaperInfo.second);
-        KConfigGroup cfg = wallpaperConfig(wallpaperInfo.first);
-        //kDebug() << "making a" << wallpaperInfo.first << "in mode" << wallpaperInfo.second;
+        d->wallpaper->setRenderingMode(mode);
+        KConfigGroup cfg = wallpaperConfig(plugin);
+        //kDebug() << "making a" << plugin << "in mode" << mode;
         if (d->containment) {
             d->wallpaper->setTargetSizeHint(d->containment.data()->size());
         }
@@ -523,18 +540,23 @@ void BackgroundDialog::saveConfig()
         return;
     }
 
-    const QString wallpaperPlugin = d->backgroundDialogUi.wallpaperMode->itemData(d->backgroundDialogUi.wallpaperMode->currentIndex()).value<WallpaperInfo>().first;
-    const QString wallpaperMode = d->backgroundDialogUi.wallpaperMode->itemData(d->backgroundDialogUi.wallpaperMode->currentIndex()).value<WallpaperInfo>().second;
-    const QString containment = d->backgroundDialogUi.containmentComboBox->itemData(d->backgroundDialogUi.containmentComboBox->currentIndex(),
+    const int wallpaperIndex = d->backgroundDialogUi.wallpaperMode->currentIndex();
+    const QString wallpaperPlugin = d->backgroundDialogUi.wallpaperMode->itemData(wallpaperIndex, AppletDelegate::PluginNameRole).toString();
+    const QString wallpaperMode = d->backgroundDialogUi.wallpaperMode->itemData(wallpaperIndex, AppletDelegate::ModeRole).toString();
+    const QString containmentPlugin = d->backgroundDialogUi.containmentComboBox->itemData(d->backgroundDialogUi.containmentComboBox->currentIndex(),
                                                           AppletDelegate::PluginNameRole).toString();
 
     // Containment
-    if (isLayoutChangeable() && d->containment) {
-        if (d->containment.data()->pluginName() != containment) {
-            disconnect(d->containment.data(), SIGNAL(destroyed()), this, SLOT(close()));
-            disconnect(this, 0, d->containment.data(), 0);
+    if (isLayoutChangeable()) {
+        if (!d->containment || d->containment.data()->pluginName() != containmentPlugin) {
+            if (d->containment) {
+                disconnect(d->containment.data(), SIGNAL(destroyed()), this, SLOT(close()));
+                disconnect(this, 0, d->containment.data(), 0);
+            }
 
-            d->containment = d->view->swapContainment(d->containment.data(), containment);
+            Plasma::Containment *containment = d->view->swapContainment(d->containment.data(), containmentPlugin);
+            if (containment != d->containment.data()) {
+                d->containment = containment;
             emit containmentPluginChanged(d->containment.data());
 
             //remove all pages but our own
@@ -573,6 +595,7 @@ void BackgroundDialog::saveConfig()
                 connect(this, SIGNAL(okClicked()), d->containment.data(), SLOT(configDialogFinished()));
             }
             connect(d->containment.data(), SIGNAL(destroyed()), this, SLOT(close()));
+            }
         }
 
         // Wallpaper
