@@ -113,13 +113,13 @@ void Task::refreshIcon()
     TaskChanges changes = TaskUnchanged;
 
     if (d->info.windowClassClass() != info.windowClassClass() ||
-            d->info.windowClassName() != info.windowClassName()) {
+        d->info.windowClassName() != info.windowClassName()) {
         changes |= ClassChanged;
     }
 
     if (d->info.visibleName() != info.visibleName() ||
-            d->info.visibleNameWithState() != info.visibleNameWithState() ||
-            d->info.name() != info.name()) {
+        d->info.visibleNameWithState() != info.visibleNameWithState() ||
+        d->info.name() != info.name()) {
         changes |= NameChanged;
     }
 
@@ -232,7 +232,18 @@ bool Task::isOnAllDesktops() const
 
 bool Task::isActive() const
 {
-    return d->active;
+    if (d->active) {
+        return true;
+    }
+
+    const WId activeWindow = KWindowSystem::activeWindow();
+    foreach (WId window, d->transients) {
+        if (activeWindow == window) {
+            return true;
+        }
+    }
+
+    return false;
 }
 
 bool Task::isOnTop() const
@@ -270,6 +281,28 @@ bool Task::isOnScreen(int screen) const
     return TaskManager::isOnScreen(screen, d->win);
 }
 
+int Task::screen() const
+{
+    int rv = -1;
+    if (!d->info.valid(true)) {
+        return rv;
+    }
+
+    QDesktopWidget *desktop = qApp->desktop();
+    int area = 0;
+
+    for (int i = 0; i < desktop->screenCount(); ++i) {
+        const QRect desktopGeometry = desktop->screenGeometry(i);
+        const QRect onScreen = desktopGeometry.intersected(d->info.geometry());
+        if (onScreen.height() * onScreen.width() > area) {
+            area = onScreen.height() * onScreen.width();
+            rv = i;
+        }
+    }
+
+    return rv;
+}
+
 bool Task::showInTaskbar() const
 {
     return d->info.state() ^ NET::SkipTaskbar;
@@ -461,6 +494,7 @@ void Task::toggleMaximized()
 
 void Task::setIconified(bool iconify)
 {
+    kDebug() <<" going to iconify" << d->win;
     if (iconify) {
         KWindowSystem::minimizeWindow(d->win);
     } else {
