@@ -114,12 +114,14 @@ public:
     MenuLauncherApplet::FormatType formattype;
     int maxRecentApps;
     bool showMenuTitles;
+    bool showRecentlyInstalled;
 
     QListWidget *view;
     KIconButton *iconButton;
     KComboBox *formatComboBox;
     QSpinBox *recentApplicationsSpinBox;
     QCheckBox *showMenuTitlesCheckBox;
+    QCheckBox *showRecentlyInstalledCheckBox;
 
     QList<QAction*> actions;
     QAction* switcher;
@@ -137,6 +139,7 @@ public:
               iconButton(0),
               formatComboBox(0),
               showMenuTitlesCheckBox(0),
+              showRecentlyInstalledCheckBox(0),
               switcher(0),
               contextMenuFactory(0)
     {}
@@ -485,7 +488,13 @@ void MenuLauncherApplet::createConfigurationInterface(KConfigDialog *parent)
     d->showMenuTitlesCheckBox->setChecked(d->showMenuTitles);
     grid->addWidget(d->showMenuTitlesCheckBox, 3, 1);
 
-    grid->addItem(new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding), 4, 0, 1, 3);
+    QLabel *showMenuRecentlyInstalledLabel = new QLabel(i18n("Show 'Recently Installed':"), p);
+    grid->addWidget(showMenuRecentlyInstalledLabel, 4, 0, Qt::AlignRight);
+    d->showRecentlyInstalledCheckBox = new QCheckBox(p);
+    d->showRecentlyInstalledCheckBox->setChecked(d->showRecentlyInstalled);
+    grid->addWidget(d->showRecentlyInstalledCheckBox, 4, 1);
+
+    grid->addItem(new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding), 5, 0, 1, 3);
     parent->addPage(p, i18n("Options"), "configure");
 
     connect(parent, SIGNAL(applyClicked()), this, SLOT(configAccepted()));
@@ -494,6 +503,7 @@ void MenuLauncherApplet::createConfigurationInterface(KConfigDialog *parent)
     connect(d->formatComboBox, SIGNAL(currentIndexChanged(QString)), parent, SLOT(settingsModified()));
     connect(d->recentApplicationsSpinBox, SIGNAL(valueChanged(int)), parent, SLOT(settingsModified()));
     connect(d->showMenuTitlesCheckBox, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
+    connect(d->showRecentlyInstalledCheckBox, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
     connect(d->view, SIGNAL(currentTextChanged(QString)), parent, SLOT(settingsModified()));    
 }
 
@@ -552,6 +562,13 @@ void MenuLauncherApplet::configAccepted()
         cg.writeEntry("showMenuTitles", showMenuTitles);
     }
 
+    const bool showRecentlyInstalled = d->showRecentlyInstalledCheckBox->isChecked();
+    if (showRecentlyInstalled != d->showRecentlyInstalled) {
+        needssaving = true;
+        d->showRecentlyInstalled = showRecentlyInstalled;
+        cg.writeEntry("showRecentlyInstalled", showRecentlyInstalled);
+    }
+
     if (needssaving) {
         d->updateTooltip();
         emit configNeedsSaving();
@@ -610,13 +627,14 @@ void MenuLauncherApplet::showMenu(bool pressed)
         foreach(const QString &vtname, d->viewtypes) {
             if(vtname == "Applications") {
                 Kickoff::ApplicationModel *appModel = new Kickoff::ApplicationModel(menuview, true /*allow separators*/);
-
+                appModel->setApplet(this);
                 appModel->setDuplicatePolicy(Kickoff::ApplicationModel::ShowLatestOnlyPolicy);
                 if (d->formattype == Name || d->formattype == NameDescription || d->formattype == NameDashDescription) {
                     appModel->setNameDisplayOrder(Kickoff::NameBeforeDescription);
                     appModel->setPrimaryNamePolicy(Kickoff::ApplicationModel::AppNamePrimary);
                 }
                 appModel->setSystemApplicationPolicy(Kickoff::ApplicationModel::ShowApplicationAndSystemPolicy);
+                appModel->setShowRecentlyInstalled(d->showRecentlyInstalled);
 
                 menuview->addModel(appModel, Kickoff::MenuView::None, d->relativePath);
 
@@ -873,6 +891,7 @@ void MenuLauncherApplet::configChanged()
 
     d->setMaxRecentApps(cg.readEntry("maxRecentApps", qMin(5, Kickoff::RecentApplications::self()->maximum())));
     d->showMenuTitles = cg.readEntry("showMenuTitles", false);
+    d->showRecentlyInstalled = cg.readEntry("showRecentlyInstalled", true);
 
     d->icon->setIcon(KIcon(cg.readEntry("icon", d->iconname)));
 
