@@ -26,6 +26,7 @@
 #include <QDeclarativeEngine>
 #include <QDeclarativeComponent>
 
+#include <KAuthorized>
 #include <KStandardDirs>
 #include <KServiceTypeTrader>
 #include <knewstuff3/downloaddialog.h>
@@ -33,6 +34,7 @@
 #include <KWindowSystem>
 
 #include <plasma/containment.h>
+#include <plasma/corona.h>
 #include <plasma/package.h>
 #include <plasma/widgets/declarativewidget.h>
 
@@ -309,4 +311,14 @@ QString ActivityManager::chooseIcon() const
     return icon;
 }
 
+bool ActivityManager::canAddActivities() const
+{
+    return KAuthorized::authorize("plasma-desktop/add_activities");
+}
+
+bool ActivityManager::canAddWidgets() const
+{
+    return d->containment && d->containment->corona()->immutability() == Plasma::Mutable;
+}
+
 #include "activitymanager.moc"
