@@ -198,26 +198,13 @@ function updateBrightness(source) {
         return;
     }
     dialogItem.disableBrightnessUpdate = true;
-    if (source.data["PowerDevil"]["Screen Brightness"]) {
+    if (typeof source.data["PowerDevil"]["Screen Brightness"] === 'number') {
         dialogItem.screenBrightness = source.data["PowerDevil"]["Screen Brightness"];
+        dialogItem.screenBrightnessPercentage = source.data["PowerDevil"]["Screen Brightness"];
     }
-    if (source.data["PowerDevil"]["Keyboard Brightness"]) {
+    if (typeof source.data["PowerDevil"]["Keyboard Brightness"] === 'number') {
         dialogItem.keyboardBrightness = source.data["PowerDevil"]["Keyboard Brightness"];
+        dialogItem.keyboardBrightnessPercentage = source.data["PowerDevil"]["Keyboard Brightness"];
     }
     dialogItem.disableBrightnessUpdate = false;
 }
-
-// TODO: give translated and formatted string with KGlobal::locale()->prettyFormatDuration(msec);
-function formatDuration(msec) {
-    if (msec == 0 || msec === undefined)
-        return "";
-
-    var time = new Date(msec);
-    var hours = time.getUTCHours();
-    var minutes = time.getUTCMinutes();
-
-    var str = "";
-    if (hours > 0) str += i18np("1 hour ", "%1 hours ", hours);
-    if (minutes > 0) str += i18np("1 minute", "%1 minutes", minutes);
-    return str;
-}
