@@ -29,6 +29,13 @@
 
 #include <QObject>
 
+
+class BuildQuery {
+public:
+    virtual QString query(QSqlDatabase *database) const = 0;
+    virtual ~BuildQuery() {}
+};
+
 class FetchSqlite : public QObject
 {
     Q_OBJECT
@@ -38,6 +45,7 @@ public:
     void prepare();
     void teardown();
     QList<QVariantMap> query(const QString &sql, QMap<QString,QVariant> bindObjects);
+    QList<QVariantMap> query(BuildQuery *buildQuery, QMap<QString,QVariant> bindObjects);
     QList<QVariantMap> query(const QString &sql);
 
 private:
