@@ -21,7 +21,6 @@
 #define CALCULATORRUNNER_H
 
 #include <QMimeData>
-#include <QRegExp>
 
 #ifdef ENABLE_QALCULATE
 class QalculateEngine;
@@ -51,8 +50,6 @@ class CalculatorRunner : public Plasma::AbstractRunner
         void powSubstitutions(QString& cmd);
         void hexSubstitutions(QString& cmd);
 
-        QRegExp m_regExp;
-
         #ifdef ENABLE_QALCULATE
         QalculateEngine* m_engine;
         #endif
